//MRGCPYJ3 JOB SIMOTIME,CLASS=1,MSGCLASS=0,NOTIFY=CSIP1
//* *******************************************************************
//*       MRGCPYJ3.jcl - a JCL Member for Batch Job Processing        *
//*       This JCL Member is provided by SimoTime Technologies        *
//*           (C) Copyright 1987-2016 All Rights Reserved             *
//*             Web Site URL:   http://www.simotime.com               *
//*                   e-mail:   helpdesk@simotime.com                 *
//* *******************************************************************
//*
//* Text   - Merge three files into one file using SORT.
//* Author - SimoTime Technologies
//* Date   - January 24, 1996
//*
//* Step 1, JOBSETUP will delete any previously created file.
//* Step 2, UTCONVS2 will convert 60-byte LRECL to 80-byte LRECL.
//* Step 3, UTCONVS3 will convert 40-byte LRECL to 80-byte LRECL.
//* Step 4, APPEND03 will merge 3 files into one (1) using SORT.
//*
//* This job uses instream sorting specifications.
//*
//* This job will run on a Mainframe System under ZOS or a Linux,
//* UNIX or Windows System and Micro Focus Enterprise Developer.
//*
//* 1. Demonstrate how to use IEFBR14 with DD statements to delete
//*    files that have been created by a previous execution of this
//*    job.
//* 2. Demonstrate how to use JCL with the SORT program to convert
//*    a file with 60-byte fixed length records to a file with 80-byte
//*    fixed length records.
//* 3. Demonstrate how to use JCL with the SORT program to convert
//*    a file with 40-byte fixed length records to a file with 80-byte
//*    fixed length records.
//* 4. Demonstrate how to use JCL with the SORT program to append
//*    or concatenate three (3) files into a single file. The SORTIN
//*    will use concatenated DD statements.
//*
//* *******************************************************************
//* Step 1 of 4, Delete any previously created file...
//*
//JOBSETUP EXEC PGM=IEFBR14
//MRGOUTD3 DD  DSN=SIMOTIME.DATA.MRGOUTD3,DISP=(MOD,DELETE,DELETE),
//             STORCLAS=MFI,
//             SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=80,DSORG=PS)
//MRG060T1 DD  DSN=SIMOTIME.DATA.MRG060T1,DISP=(MOD,DELETE,DELETE),
//             STORCLAS=MFI,
//             SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=80,DSORG=PS)
//MRG040T1 DD  DSN=SIMOTIME.DATA.MRG040T1,DISP=(MOD,DELETE,DELETE),
//             STORCLAS=MFI,
//             SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=80,DSORG=PS)
//*
//* *******************************************************************
//* Step 2 of 4, Convert Sequential file with 60-byte records
//*              to a Sequential file with 80-byte records...
//*
//UTCONVS2 EXEC PGM=SORT,
//             REGION=1024K
//SYSIN    DD  *
* ..:....1....:....2....:....3....:....4....:....5....:....6....:....7.
         SORT FIELDS=COPY
         INREC FIELDS=(1:1,60)
         OUTREC FIELDS=(1:1,60)
/*
//SORTIN   DD  DSN=SIMOTIME.DATA.MRG060D1,DISP=SHR
//SORTOUT  DD  DSN=SIMOTIME.DATA.MRG060T1,
//             DISP=(NEW,CATLG,DELETE),
//             STORCLAS=MFI,
//             SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=80,DSORG=PS)
//SYSOUT   DD  SYSOUT=*
//*
//* *******************************************************************
//* Step 3 of 4, Convert Sequential file with 40-byte records
//*              to a Sequential file with 80-byte records...
//*
//UTCONVS3 EXEC PGM=SORT,
//             REGION=1024K
//SYSIN    DD  *
* ..:....1....:....2....:....3....:....4....:....5....:....6....:....7.
         SORT FIELDS=COPY
         INREC FIELDS=(1:1,40)
         OUTREC FIELDS=(1:1,40)
/*
//SORTIN   DD  DSN=SIMOTIME.DATA.MRG040D1,DISP=SHR
//SORTOUT  DD  DSN=SIMOTIME.DATA.MRG040T1,
//             DISP=(NEW,CATLG,DELETE),
//             STORCLAS=MFI,
//             SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=80,DSORG=PS)
//SYSOUT   DD  SYSOUT=*
//*
//* *******************************************************************
//* Step 4 of 4, Merge the three (3) files into one (1) file,
//*              Concatenated data files may be used as input since all
//*              the files to be merged are now the same record length.
//*
//APPEND03 EXEC PGM=SORT,
//             REGION=1024K
//SYSIN    DD  *
* ..:....1....:....2....:....3....:....4....:....5....:....6....:....7.
         SORT FIELDS=COPY
         INREC FIELDS=(1:1,80)
         OUTREC FIELDS=(1:1,80)
/*
//SORTIN   DD  DSN=SIMOTIME.DATA.MRG080D1,DISP=SHR
//         DD  DSN=SIMOTIME.DATA.MRG060T1,DISP=SHR
//         DD  DSN=SIMOTIME.DATA.MRG040T1,DISP=SHR
//SORTOUT  DD  DSN=SIMOTIME.DATA.MRGOUTD3,
//             DISP=(NEW,CATLG,DELETE),
//             STORCLAS=MFI,
//             SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=80,DSORG=PS)
//SYSOUT   DD  SYSOUT=*
//*
//
